Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3698)

Unified Diff: chrome/browser/ui/views/frame/browser_view_layout.h

Issue 6913026: Compact Navigation prototype (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: Added missing DropdownBarHostDelegate header file. Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/browser_view_layout.h
===================================================================
--- chrome/browser/ui/views/frame/browser_view_layout.h (revision 84320)
+++ chrome/browser/ui/views/frame/browser_view_layout.h (working copy)
@@ -62,9 +62,11 @@
Browser* browser();
const Browser* browser() const;
- // Layout the TabStrip, returns the coordinate of the bottom of the TabStrip,
- // for laying out subsequent controls.
- virtual int LayoutTabStrip();
+ // Layout the tab strip region, returns the coordinate of the bottom of the
+ // TabStrip, for laying out subsequent controls. This also lays out the
+ // compact navigation and options bars if the browser is in compact navigation
+ // mode.
+ virtual int LayoutTabStripRegion();
// Layout the following controls, starting at |top|, returns the coordinate
// of the bottom of the control, for laying out the next control.
@@ -112,6 +114,9 @@
views::SingleSplitView* contents_split_;
ContentsContainer* contents_container_;
views::View* infobar_container_;
+ views::View* compact_navigation_bar_;
+ views::View* compact_options_bar_;
+ views::View* spacer_;
sky 2011/05/09 14:27:22 compact_spacer_
SteveT 2011/05/09 19:40:04 Done here and everywhere (and in browser_view.*).
DownloadShelfView* download_shelf_;
BookmarkBarView* active_bookmark_bar_;

Powered by Google App Engine
This is Rietveld 408576698